@@ -1,4 +1,4 @@
-from procuret.session import Session, Lifecycle, Perspective
+from procuret.session import Session, Lifecycle, Perspective, AbstractSession
 from procuret.ancillary.communication_option import CommunicationOption
 from procuret.instalment_link import InstalmentLink, InstalmentLinkOpen
 from procuret.instalment_link import InstalmentLinkOrderBy
@@ -17,4 +17,5 @@ from procuret.data.codable import Codable, CodingDefinition
 from procuret.global_brand.brand import GlobalBrand
 from procuret.global_brand.selection import GlobalBrandSelection
 from procuret.payment_series.series import PaymentSeries
-from procuret.customer_payment.payment import CustomerPayment
+from procuret.customer_payment import CustomerPayment
+
